@@ -21,7 +21,10 @@
   TableList.prototype.tables = function() {
     var parameters = this.parameters();
     return this.body().slice(1).map(function(tableProperties) {
-      var table = {};
+      var table = {
+        properties: {},
+        rawProperties: tableProperties
+      };
       parameters.forEach(function(parameter, index) {
         var name = parameter.name;
         var value = tableProperties[index];
@@ -29,17 +32,31 @@
         case 'flags':
           value = value.split('|');
           break;
-        case 'source':
-          name = 'sources';
+        case 'default_tokenizer':
+          name = 'tokenizer';
+          break;
+        case 'token_filters':
+          name = 'tokenFilters';
           break;
         }
-        table[name] = value;
+        table[name] = table.properties[name] = value;
       });
-      table.isArray          = table.flags.indexOf('TABLE_NO_KEY')   != -1;
-      table.isHashTable      = table.flags.indexOf('TABLE_HASH_KEY') != -1;
-      table.isPatriciaTrie   = table.flags.indexOf('TABLE_PAT_KEY')  != -1;
-      table.isDoublArrayTrie = table.flags.indexOf('TABLE_DAT_KEY')  != -1;
+      table.isArray           = table.flags.indexOf('TABLE_NO_KEY')   != -1;
+      table.isHashTable       = table.flags.indexOf('TABLE_HASH_KEY') != -1;
+      table.isPatriciaTrie    = table.flags.indexOf('TABLE_PAT_KEY')  != -1;
+      table.isDoubleArrayTrie = table.flags.indexOf('TABLE_DAT_KEY')  != -1;
       table.hasKey = !table.isArray;
+      if (table.isArray) {
+        table.type = 'array';
+      } else if (table.isHashTable) {
+        table.type = 'hash table';
+      } else if (table.isPatriciaTrie) {
+        table.type = 'patricia trie';
+      } else if (table.isDoubleArrayTrie) {
+        table.type = 'double array trie';
+      } else {
+        table.type = 'unknown';
+      }
       return table;
     });
   };
